/*
 * gulkan
 * Copyright 2018 Collabora Ltd.
 * Author: Lubosz Sarnecki <lubosz.sarnecki@collabora.com>
 * SPDX-License-Identifier: MIT
 */

#pragma once

#ifndef GULKAN_H
#define GULKAN_H

#include <glib.h>

#define GULKAN_INSIDE

#include "gulkan-version.h"
#include "gulkan-client.h"
#include "gulkan-cmd-buffer.h"
#include "gulkan-device.h"
#include "gulkan-frame-buffer.h"
#include "gulkan-geometry.h"
#include "gulkan-instance.h"
#include "gulkan-renderer.h"
#include "gulkan-texture.h"
#include "gulkan-uniform-buffer.h"
#include "gulkan-vertex-buffer.h"
#include "gulkan-render-pass.h"
#include "gulkan-swapchain.h"
#include "gulkan-descriptor-pool.h"
#include "gulkan-swapchain-renderer.h"
#include "gulkan-buffer.h"
#include "gulkan-queue.h"

#undef GULKAN_INSIDE


#endif /* __GULKAN_H__ */
